# Optional Terms & Conditions

These Terms & Conditions supplement the basic Terms & Conditions for our Services. You are free to use our Services without agreeing to this Supplement.

This Supplement will allow us to carry out a research project impossible without a large centralized repository of topography data. We kindly ask you to consider agreeing to this Supplement and thereby support our research efforts in reciprocity for using the Services.

## Additional permissions for statistical analysis of your data

By using our Services, you may provide us with information and files (your data). By agreeing to these optional conditions you give permission to us to inspect your data and run statistical analyses on your data. By "us" we are referring to the principal investigators

* Prof. Tevis Jacobs, University of Pittsburgh
* Prof. Lars Pastewka, University of Freiburg, the operator of this site
* Prof. Mark O. Robbins, Johns Hopkins University

and by extension members of the respective research groups. By statistical analysis we mean, for example, computing global bounds on scalar roughness parameters such as the root-mean-square slope and height or classification using machine learning techniques such as the support vector machine. These analyses are part of a [research project](https://cordis.europa.eu/project/rcn/212185/factsheet/en) funded by the European Research Council on how surface roughness emerges. We want identify recurring patterns that would allow to identify, for example, the processing history of a piece of material from its surface, as practiced for example in fractography.

We may decide to publish part of this statistical information in form of a journal publication or present it at conferences. No form of dissemination will happen without us asking for your consent. We will offer you co-authorship in accordance with the rules for [European Code of Conduct for Research Integrity](http://www.allea.org/wp-content/uploads/2017/03/ALLEA-European-Code-of-Conduct-for-Research-Integrity-2017-1.pdf) and the rules for [Good Scientific Practice of the Deutsche Forschungsgemeinschaft](http://doi.org/10.1002/9783527679188.oth1). Let us make it clear that we will under no circumstances publish your data and results derived from it without obtaining written permission from you to do so.

## Contacting you

By agreeing to this Supplement, you also give permission to contact you via the e-mail address registered on our site. We may contact you to discuss publication of derived data or to ask you to provide additional metadata on topographies uploaded by you. More broadly, you give us permission to contact you to start a scientific discussion on patterns we may find in your data.
